==> nextcloud-27.1.11.tgz: nextcloud/apps/systemtags/l10n/ast.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "El sistema amestó la etiqueta del sistema «%1$s»",
    "Added system tag {systemtag}" : "Amestóse la etiqueta del sistema «{systemtag}»",
    "Added system tag %1$s" : "Amestóse la etiqueta del sistema «%1$s»",
    "%1$s added system tag %2$s" : "%1$s amestó la etiqueta del sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} amestó la etiqueta del sistema {systemtag}",
    "System tag %1$s removed by the system" : "El sistema quitó la etiqueta del sistema «%1$s»",
    "Removed system tag {systemtag}" : "Quitóse la etiqueta del sistema «{systemtag}»",
    "Removed system tag %1$s" : "Quitóse la etiqueta del sistema «%1$s»",
    "%1$s removed system tag %2$s" : "%1$s quitó la etiqueta del sistema «%2$s»",
    "{actor} removed system tag {systemtag}" : "{actor} quitó la etiqueta del sistema «{systemtag}»",
    "You created system tag %1$s" : "Creesti la etiqueta del sistema «%1$s»",
    "You created system tag {systemtag}" : "Creesti la etiqueta del sistema «{systemtag}»",
    "%1$s created system tag %2$s" : "%1$s creó la etiqueta del sistema «%2$s»",
    "{actor} created system tag {systemtag}" : "{actor} creó la etiqueta del sistema «{systemtag}»",
    "You deleted system tag %1$s" : "Desaniciesti la etiqueta del sistema «%1$s»",
    "You deleted system tag {systemtag}" : "Desaniciesti la etiqueta del sistema «{systemtag}»",
    "%1$s deleted system tag %2$s" : "%1$s desanició la etiqueta del sistema «%2$s»",
    "{actor} deleted system tag {systemtag}" : "{actor} desanició la etiqueta del sistema «{systemtag}»",
    "You updated system tag %2$s to %1$s" : "Anovesti la etiqueta del sistema «%2$s» a «%1$s»",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Anovesti la etiqueta del sistema «{oldsystemtag}» a «{newsystemtag}»",
    "%1$s updated system tag %3$s to %2$s" : "%1$s anovó la etiqueta del sistema «%3$s» a «%2$s»",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} anovó la etiqueta del sistema «{oldsystemtag}» a «{newsystemtag}»",
    "System tag %2$s was added to %1$s by the system" : "El sistema amestó la etiqueta del sistema «%2$s» a «%1$s»",
    "System tag {systemtag} was added to {file} by the system" : "El sistema amestó la etiqueta del sistema «{systemtag}» a «{file}»",
    "You added system tag %2$s to %1$s" : "Amestesti la etiqueta del sistema «%2$s» a «%1$s»",
    "You added system tag {systemtag} to {file}" : "Amestesti la etiqueta del sistema «{systemtag}» a «{file}»",
    "%1$s added system tag %3$s to %2$s" : "%1$s amestó la etiqueta del sistema «%3$s» a «%2$s»",
    "{actor} added system tag {systemtag} to {file}" : "«{actor}» amestó la etiqueta del sistema «{systemtag}» a «{file}»",
    "System tag %2$s was removed from %1$s by the system" : "El sistema quitó la etiqueta del sistema «%2$s» de: %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "El sistema quitó la etiqueta del sistema «{systemtag}» de: {file}",
    "You removed system tag %2$s from %1$s" : "Quitesti la etiqueta del sistema %2$s de: %1$s",
    "You removed system tag {systemtag} from {file}" : "Quitesti la etiqueta del sistema {systemtag} de: {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s quitó la etiqueta del sistema %3$s de: %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} quitó la etiqueta del sistema {systemtag} de: {file}",
    "%s (restricted)" : "%s (restrinxóse)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "Modificáronse les <strong>etiquetes del sistema</strong> pa un ficheru",
    "Tags" : "Etiquetes",
    "All tagged %s …" : "Tolos elementos cola etiqueta «%s»…",
    "tagged %s" : "elementos etiquetaos con «%s»",
    "Collaborative tags" : "Etiquetes collaboratives",
    "Collaborative tagging functionality which shares tags among people." : "La función d'etiquetes collaboratives que comparte etiquetes ente persones.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "La función d'etiquetes collaboratives que comparte etiquetes ente persones. Ideal pa equipos.\n\t(si yes un fornidor con una instalación diversos veceros, aconséyase desactivar esta aplicación darréu que se comparten les etiquetes).",
    "Create or edit tags" : "Crear o editar etiquetes",
    "Search for a tag to edit" : "Buscar una etiqueta pa editar",
    "Collaborative tags …" : "Etiquetes collaboratives…",
    "No tags to select" : "Nun hai nenguna etiqueta pa seleicionar",
    "Tag name" : "Nome de la etiqueta",
    "Tag level" : "Nivel de la etiqueta",
    "Create" : "Crear",
    "Update" : "Anovar",
    "Delete" : "Desaniciar",
    "Reset" : "Reafitar",
    "Loading …" : "Cargando…",
    "Public" : "Pública",
    "Restricted" : "Restrinxóse",
    "Invisible" : "Invisible",
    "Created tag" : "Etiqueta creada",
    "Failed to create tag" : "Nun se pue crear la etiqueta",
    "Updated tag" : "Anovar la etiqueta",
    "Failed to update tag" : "Nun se pue anovar la etiqueta",
    "Deleted tag" : "Desaniciar la etiqueta",
    "Failed to delete tag" : "Nun se pue desaniciar la etiqueta",
    "Loading collaborative tags …" : "Cargando les etiquetes collaboratives…",
    "Search or create collaborative tags" : "Buscar o crear etiquetes collaboratives",
    "No tags to select, type to create a new tag" : "Nun hai nenguna etiqueta pa seleicionar, escribir pa crear una etiqueta",
    "Failed to load tags" : "Nun se puen cargar les etiquetes",
    "Failed to load selected tags" : "Nun se puen cargar les etiquetes seleicionaes",
    "Failed to select tag" : "Nun se pue seleicionar la etiqueta",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Les etiquetes collaboratives tán disponibles pa tolos usuarios. Los usuarios puen ver les etiquetes restrinxíes mas nun les puen asignar. Les etiquetes invisibles pa usu internu, darréu que los usuarios nun puen vele o asignales.",
    "This file has the tag {tag}" : "Esti ficheru tien la etiqueta «{tag}»",
    "This file has the tags {firstTags} and {lastTag}" : "Esti ficheru tien les etiquetes «{firstTags}» y «{lastTag}»",
    "List of tags and their associated files and folders." : "Una llista d'etiquetes y los sos ficheros y carpetes asociaos.",
    "No tags found" : "Nun s'atopó nenguna etiqueta",
    "Tags you have created will show up here." : "Equí apaecen les etiquetes que crees.",
    "Failed to load last used tags" : "Nun se puen cargar les últimes etiquetes usaes",
    "Missing \"Content-Location\" header" : "Falta la peñera «Content-Location»",
    "Failed to load tags for file" : "Nun se puen cargar les etiquetes pal ficheru",
    "Failed to set tag for file" : "Nun se puen afitar la etiqueta pal ficheru",
    "Failed to delete tag for file" : "Nun se pue desaniciar la etiqueta pal ficheru",
    "Tag name is empty" : "El nome de la etiqueta ta baleru",
    "Select tag …" : "Seleicionar una etiqueta…",
    "Collaborative tagging functionality which shares tags among users." : "La función d'etiquetes collaboratives que comparte etiquetes ente usuarios.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "La función d'etiquetes collaboratives que comparte etiquetes ente usuarios. Ideal pa equipos.\n\t(si yes un fornidor con una instalación diversos veceros, aconséyase desactivar esta aplicación darréu que se comparten les etiquetes).",
    "Tagged files" : "Ficheros etiquetaos",
    "Select tags to filter by" : "Seleiciona les etiquetes polos que quies peñerar",
    "Please select tags to filter by" : "Seleiciona les etiquetes poles que quies peñerar",
    "No files found for the selected tags" : "Nun s'atopó nengún ficheru pa les etiquetes seleicionaes",
    "Create a new tag" : "Crear una etiqueta",
    "Name" : "Nome",
    "No files in here" : "Nun hai ficheros",
    "No entries found in this folder" : "Nun s'atopó nenguna entrada nesta carpeta",
    "Size" : "Tamañu",
    "Modified" : "Modificóse"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.9.tgz: nextcloud/apps/systemtags/l10n/ast.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "El sistema amestó la etiqueta del sistema «%1$s»",
    "Added system tag {systemtag}" : "Amestóse la etiqueta del sistema «{systemtag}»",
    "Added system tag %1$s" : "Amestóse la etiqueta del sistema «%1$s»",
    "%1$s added system tag %2$s" : "%1$s amestó la etiqueta del sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} amestó la etiqueta del sistema {systemtag}",
    "System tag %1$s removed by the system" : "El sistema quitó la etiqueta del sistema «%1$s»",
    "Removed system tag {systemtag}" : "Quitóse la etiqueta del sistema «{systemtag}»",
    "Removed system tag %1$s" : "Quitóse la etiqueta del sistema «%1$s»",
    "%1$s removed system tag %2$s" : "%1$s quitó la etiqueta del sistema «%2$s»",
    "{actor} removed system tag {systemtag}" : "{actor} quitó la etiqueta del sistema «{systemtag}»",
    "You created system tag %1$s" : "Creesti la etiqueta del sistema «%1$s»",
    "You created system tag {systemtag}" : "Creesti la etiqueta del sistema «{systemtag}»",
    "%1$s created system tag %2$s" : "%1$s creó la etiqueta del sistema «%2$s»",
    "{actor} created system tag {systemtag}" : "{actor} creó la etiqueta del sistema «{systemtag}»",
    "You deleted system tag %1$s" : "Desaniciesti la etiqueta del sistema «%1$s»",
    "You deleted system tag {systemtag}" : "Desaniciesti la etiqueta del sistema «{systemtag}»",
    "%1$s deleted system tag %2$s" : "%1$s desanició la etiqueta del sistema «%2$s»",
    "{actor} deleted system tag {systemtag}" : "{actor} desanició la etiqueta del sistema «{systemtag}»",
    "You updated system tag %2$s to %1$s" : "Anovesti la etiqueta del sistema «%2$s» a «%1$s»",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Anovesti la etiqueta del sistema «{oldsystemtag}» a «{newsystemtag}»",
    "%1$s updated system tag %3$s to %2$s" : "%1$s anovó la etiqueta del sistema «%3$s» a «%2$s»",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} anovó la etiqueta del sistema «{oldsystemtag}» a «{newsystemtag}»",
    "System tag %2$s was added to %1$s by the system" : "El sistema amestó la etiqueta del sistema «%2$s» a «%1$s»",
    "System tag {systemtag} was added to {file} by the system" : "El sistema amestó la etiqueta del sistema «{systemtag}» a «{file}»",
    "You added system tag %2$s to %1$s" : "Amestesti la etiqueta del sistema «%2$s» a «%1$s»",
    "You added system tag {systemtag} to {file}" : "Amestesti la etiqueta del sistema «{systemtag}» a «{file}»",
    "%1$s added system tag %3$s to %2$s" : "%1$s amestó la etiqueta del sistema «%3$s» a «%2$s»",
    "{actor} added system tag {systemtag} to {file}" : "«{actor}» amestó la etiqueta del sistema «{systemtag}» a «{file}»",
    "System tag %2$s was removed from %1$s by the system" : "El sistema quitó la etiqueta del sistema «%2$s» de: %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "El sistema quitó la etiqueta del sistema «{systemtag}» de: {file}",
    "You removed system tag %2$s from %1$s" : "Quitesti la etiqueta del sistema %2$s de: %1$s",
    "You removed system tag {systemtag} from {file}" : "Quitesti la etiqueta del sistema {systemtag} de: {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s quitó la etiqueta del sistema %3$s de: %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} quitó la etiqueta del sistema {systemtag} de: {file}",
    "%s (restricted)" : "%s (restrinxóse)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "Modificáronse les <strong>etiquetes del sistema</strong> pa un ficheru",
    "Files" : "Ficheros",
    "Tags" : "Etiquetes",
    "All tagged %s …" : "Tolos elementos cola etiqueta «%s»…",
    "tagged %s" : "elementos etiquetaos con «%s»",
    "Collaborative tags" : "Etiquetes collaboratives",
    "Collaborative tagging functionality which shares tags among people." : "La función d'etiquetes collaboratives que comparte etiquetes ente persones.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "La función d'etiquetes collaboratives que comparte etiquetes ente persones. Ideal pa equipos.\n\t(si yes un fornidor con una instalación diversos veceros, aconséyase desactivar esta aplicación darréu que se comparten les etiquetes).",
    "Create or edit tags" : "Crear o editar etiquetes",
    "Search for a tag to edit" : "Buscar una etiqueta pa editar",
    "Collaborative tags …" : "Etiquetes collaboratives…",
    "No tags to select" : "Nun hai nenguna etiqueta pa seleicionar",
    "Tag name" : "Nome de la etiqueta",
    "Tag level" : "Nivel de la etiqueta",
    "Create" : "Crear",
    "Update" : "Anovar",
    "Delete" : "Desaniciar",
    "Reset" : "Reafitar",
    "Loading …" : "Cargando…",
    "Public" : "Pública",
    "Restricted" : "Restrinxóse",
    "Invisible" : "Invisible",
    "Created tag" : "Etiqueta creada",
    "Failed to create tag" : "Nun se pue crear la etiqueta",
    "Updated tag" : "Anovar la etiqueta",
    "Failed to update tag" : "Nun se pue anovar la etiqueta",
    "Deleted tag" : "Desaniciar la etiqueta",
    "Failed to delete tag" : "Nun se pue desaniciar la etiqueta",
    "Loading collaborative tags …" : "Cargando les etiquetes collaboratives…",
    "Search or create collaborative tags" : "Buscar o crear etiquetes collaboratives",
    "No tags to select, type to create a new tag" : "Nun hai nenguna etiqueta pa seleicionar, escribir pa crear una etiqueta",
    "Failed to load tags" : "Nun se puen cargar les etiquetes",
    "Failed to load selected tags" : "Nun se puen cargar les etiquetes seleicionaes",
    "Failed to select tag" : "Nun se pue seleicionar la etiqueta",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Les etiquetes collaboratives tán disponibles pa tolos usuarios. Los usuarios puen ver les etiquetes restrinxíes mas nun les puen asignar. Les etiquetes invisibles pa usu internu, darréu que los usuarios nun puen vele o asignales.",
    "Open in Files" : "Abrir en Ficheros",
    "List of tags and their associated files and folders." : "Una llista d'etiquetes y los sos ficheros y carpetes asociaos.",
    "No tags found" : "Nun s'atopó nenguna etiqueta",
    "Tags you have created will show up here." : "Equí apaecen les etiquetes que crees.",
    "Failed to load last used tags" : "Nun se puen cargar les últimes etiquetes usaes",
    "Missing \"Content-Location\" header" : "Falta la peñera «Content-Location»",
    "Failed to load tags for file" : "Nun se puen cargar les etiquetes pal ficheru",
    "Failed to set tag for file" : "Nun se puen afitar la etiqueta pal ficheru",
    "Failed to delete tag for file" : "Nun se pue desaniciar la etiqueta pal ficheru",
    "Collaborative tagging functionality which shares tags among users." : "La función d'etiquetes collaboratives que comparte etiquetes ente usuarios.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "La función d'etiquetes collaboratives que comparte etiquetes ente usuarios. Ideal pa equipos.\n\t(si yes un fornidor con una instalación diversos veceros, aconséyase desactivar esta aplicación darréu que se comparten les etiquetes).",
    "This file has the tag {tag}" : "Esti ficheru tien la etiqueta «{tag}»",
    "This file has the tags {firstTags} and {lastTag}" : "Esti ficheru tien les etiquetes «{firstTags}» y «{lastTag}»",
    "No files in here" : "Nun hai ficheros",
    "No entries found in this folder" : "Nun s'atopó nenguna entrada nesta carpeta",
    "Name" : "Nome",
    "Size" : "Tamañu",
    "Modified" : "Modificóse"
},
"nplurals=2; plural=(n != 1);");
